/*
 * COPYRIGHT 2015 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 */

#import <Foundation/Foundation.h>

/** The YSLinearCreative protocol provides an interface to an advert's linear creative object - if VAST is associated with the advert, and whose details are passed as a payload during analytic callbacks.
 
 */
@protocol YSLinearCreative <NSObject>

/** Returns the linear creative's identifier.
 
 @param none
 @return The identifier.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSString * _Nonnull linearIdentifier;

/** Returns the linear creative's sequence number.
 
 @param none
 @return The sequence identifier.
 @since from 1.0
 */

@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSString * _Nullable linearSequenceIdentifier;

/** Returns the nonlinear creative's Ad identifier.
 
 @param none
 @return The Ad identifier.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSString * _Nullable linearAdIdentifier;

/** Returns the linear creative's clickthrough URL.
 
 @param none
 @return The clickthrough URL.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSURL * _Nullable linearClickthroughURL;

/** Returns the linear creative's custom click URL elements.
 
 @param none
 @return The custom click URLs.
 @since from 1.2
 */
@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSArray * _Nullable customClickURLs;

/** Returns any adParameters associated with this linear creative.<br/>
    Note that the string is always XML encoded.
 
 @param none
 @return adParameters associated with this linear creative.
 @since from 1.2
 */
@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSString * _Nullable linearAdParameters;

/** Returns an array of zero or more industry icons associated with this linear creative.
 
 @param none
 @return an NSArray of YOIndustryIcon associated with this linear creative.
 @since from 1.2
 */
@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSArray * _Nonnull linearIndustryIcons;

@end
