//
//  PlayerViewController.swift
//  AmpFreewheelSample
//
//  Created by Lopez Valenciano, Miguel on 12/11/17.
//  Copyright © 2017 Akamai. All rights reserved.
//

import Foundation
import AmpCore
import AmpFreewheel
import AmpAdobeHeartbeat

class PlayerViewController: UIViewController {
    
    var ampPlayer: AmpPlayer!
    var ampFreewheel: AmpFreewheel!
    var levels:[QualityLevel]!
    var ampHeartbeat: AmpAdobeHeartbeat?
    
    let dvr = "https://authcrowntrans-vh.akamaihd.net/i/Output/delivery/eb/f0/ebf058b8-3c97-4285-8d16-22472d529104/HD_VOD_MHMLB6020_,200k_2,600k_3,4000k_1,2500k_2,800k_3,400k_1,600k_2,200k_1,4000k_2,1500k_1,400k_3,800k_1,1000k_3,1500k_3,1000k_2,2500k_3,.mp4.csmil/master.m3u8?hdnts=exp=1515107167~acl=/i/*~hmac=c873edc1367339a6704cbb68a749eb46b6a1576590e5602d52fc50e536bf2e2c"
    let vod = "http://multiplatform-f.akamaihd.net/i/multi/will/bunny/big_buck_bunny_,640x360_400,640x360_700,640x360_1000,950x540_1500,.f4v.csmil/master.m3u8"
    let live = "http://playertest.longtailvideo.com/adaptive/wowzaid3/playlist.m3u8"
    let audio = "http://nrkradio-f.akamaihd.net/i/p3_0@4275/master.m3u8"
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.ampPlayer = AmpPlayer(parentView: self.view)
        self.ampPlayer.setLicense("AwETtTXPRsvmp2oSjsKviO6DmucyCu1Lw/+590XuBHO91ePfqtGzVx1Ewrc5Lt+YWShxO5by03IIo5k0zHlY/CIPl9H5fpgV/BkubsJXWffQN9HIJthoAvH+zr142zvOZkIQFnLByWyWjSs0xcqfOEHK/xyvNshy3zdmGgfS4ol9oSY2QGP6WFMTT86pGkHCVr6Tr6vPX0PUBMf33mu/hHgszAL2uD5hNPLGKR7ZaBhwQQ==")
        self.ampPlayer.registerObserver(self)
        self.ampPlayer.isDVREnabled = true
        /*
         
         "adServerUrl": "http://29773.v.fwmrm.net",
         "networkId": 379152,
         "profile": "379152:hallmark_ios_live",
         "siteSectionId": "hallmark_ros_ios"
         "adId": "HALL_MSPLB0375"
         
         */
        
        // Heartbeat setup
        let videoMetadata = [
            AmpMetaDataKey.season: "Season 1",
            AmpMetaDataKey.show: "Best Show Ever",
            AmpMetaDataKey.episode: "Episode 4"
        ]
        
        let heartbeatConfig: [String : AnyObject] = [
            "trackingServer": "http://hallmarkcom.hb.omtrdc.net" as AnyObject,
            "jobId": "j2" as AnyObject,
            "channel": "Hallmark Channel" as AnyObject,
            "publisher": "us-108166" as AnyObject,
            "ovp": "Akamai" as AnyObject,
            "sdk": "VHL 2.x Sample Player" as AnyObject,
            "videoId": "Test Video ID" as AnyObject,
            "videoName": "Non required video Name" as AnyObject,
            //            "debugLogging": true as AnyObject,
            //            "ssl": false as AnyObject
        ]
        
        self.ampHeartbeat = AmpAdobeHeartbeat(ampPlayer: self.ampPlayer!, configuration: heartbeatConfig, videoMetadata: videoMetadata)
        
        self.ampFreewheel = AmpFreewheel(ampPlayer: self.ampPlayer!, networkId: 379152, serverUrl: "http://29773.v.fwmrm.net")

        let videoAssetId = VideoAssetId(id: "HALL_MSPLB0375", duration: 500)
        self.ampFreewheel?.requestAds(profile: "379152:hallmark_ios_live", siteSectionId: "hallmark_ros_ios", videoAssetId: videoAssetId) { adController in
            adController.addPrerollSlot("pre1")
            adController.addMidrollSlot("mid1", timePosition: 60)
            adController.addMidrollSlot("mid2", timePosition: 120)
            adController.addPostrollSlot("post1")
        }

        print("AKAMAI PLAYER VERSION: \(self.ampPlayer!.version)")
        
        self.ampPlayer.handleUrl(vod)
        self.ampPlayer.allowBackgroundPlayback = true
        self.ampPlayer.autoplay = true
        
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
}


extension PlayerViewController: PlayerEventObserver {
    
    func onBufferingStateChanged(_ ampPlayer: AmpPlayer) {
    }
    
    func onAdBreakStarted(break: AdBreakInfo?) {
        print("FWEVENT: onAdBreakStarted")
    }
    
    func onAdBreakEnded(break: AdBreakInfo?) {
        print("FWEVENT: onAdBreakEnded")
    }
    
    func onAdStarted(ad: AdInfo?) {
        print("FWEVENT: onAdStarted")
    }
    
    func onAdError() {
        print("FWEVENT: onAdError")
    }
    
    func onAdEnded(ad: AdInfo?) {
        print("FWEVENT: onAdEnded")
    }
    
    func onAdRequestCompleted() {
        print("FWEVENT: onAdRequestCompleted")
    }
    
    func onAdRequested() {
        print("FWEVENT: onAdRequested")
    }
    
}
